@@ -21,3 +21,5 @@ def ConvertJsonToDocumentsObjects(json):
         listOfDocuments.append(doc)
     return listOfDocuments
 
+def ConvertPredictionToJson(predictionTab):
+    return json.dumps(predictionTab, separators=(',', ':'))
\ No newline at end of file
